pub struct ValidContext<'a, 'ph: 'a> { /* private fields */ }
A PluginHandle operating on a valid context.

This mechanism attempts to reduce the likelihood of segfaults in hexchat code.

See also PluginHandle::ensure_valid_context.

Implementations

Finds an open context for the given servname and channel.

Compares two nicks based on the server’s case mapping.

Executes a command.

Sets the current context.

Returns true if the context is valid, false otherwise.

Prints to the hexchat buffer.

Prints to this hexchat buffer.

Glue for usage of the write! macro with hexchat.

Panics

This panics if any broken formatting trait implementations are used in the format arguments. See also format!.

Sets a command hook

Sets a server hook

Sets a server hook with attributes

Sets a print hook

Sets a print hook with attributes

Sets a timer hook